@@ -20,7 +20,7 @@ logger = logging.getLogger("dy")
 
 
 @unique
-class Language(Enum):
+class Language(str, Enum):
     JMESPATH = "jmespath"
     SQL = "sql"
 
@@ -106,7 +106,14 @@ class SQLExpression(Expression):
         self._is_single_field = True
         try:
             self._fields = json.loads(expression)
-            self._is_single_field = False
+
+            # verify this is a dict, and not a list or document ('x' is a valid json)
+            if isinstance(self._fields,dict):
+                self._is_single_field = False
+            else:
+                # this is not a dict, treat as a simple expression
+                self._fields = {"expr": expression}
+
         except json.JSONDecodeError:
             # this is not a json, treat as a simple expression
             self._fields = {"expr": expression}
@@ -183,9 +190,9 @@ def compile(language: Language, expression: str) -> Expression:
     Returns:
         Expression: Expression class
     """
-    if language == Language.JMESPATH.value:
+    if language == Language.JMESPATH:
         expression_class = JMESPathExpression()
-    elif language == Language.SQL.value:
+    elif language == Language.SQL:
         expression_class = SQLExpression()
     else:
         raise ValueError(f"unknown expression language {language}")
